PolarizeSplits: Polarize splits on a single taxon

View source: R/Splits.R

PolarizeSplitsR Documentation

Polarize splits on a single taxon

Description

Polarize splits on a single taxon

Usage

PolarizeSplits(x, pole = 1L)

Arguments

x

Object that can be coerced into class Splits.

pole

Numeric, character or logical vector identifying tip that will polarize each split.

Value

PolarizeSplits() returns a Splits object in which pole is represented by a zero bit

See Also

Other Splits operations: LabelSplits(), NSplits(), NTip(), SplitFrequency(), Splits, SplitsInBinaryTree(), TipLabels(), TipsInSplits(), match,Splits,Splits-method, xor()


TreeTools documentation built on April 23, 2026, 5:06 p.m.