TopologyOnly: Remove metadata from trees

View source: R/TopologyOnly.R

TopologyOnlyR Documentation

Remove metadata from trees

Description

TopologyOnly() removes all information from trees except for their topologies and leaf labels.

Usage

TopologyOnly(tree)

Arguments

tree

A tree of class phylo.

Value

Returns tree, with each tree in Preorder, with edge lengths, node labels and other attributes removed.

Author(s)

Martin R. Smith (martin.smith@durham.ac.uk)


TreeTools documentation built on April 23, 2026, 5:06 p.m.