Treeness: Relative length of internal branches

View source: R/Treeness.R

TreenessR Documentation

Relative length of internal branches

Description

Treeness (also termed stemminess) is the proportion of a tree's length found on internal branches \insertCiteLanyon1988TreeTools. Insofar as external branches do not contain phylogenetic (grouping) signal, trees with a high treeness can be interpreted as containing a higher signal:noise ratio \insertCitePhillips2003TreeTools.

Usage

Treeness(tree)

Stemminess(tree)

Arguments

tree

A tree of class phylo, or a list of trees of class list or multiPhylo.

Value

Treeness() returns a numeric vector reporting the treeness of each tree.

Author(s)

Martin R. Smith (martin.smith@durham.ac.uk)

References

\insertAllCited

See Also

Other tree properties: Cherries(), ConsensusWithout(), EdgeRatio(), LongBranch(), MatchEdges(), NSplits(), NTip(), NodeNumbers(), PathLengths(), SplitsInBinaryTree(), TipLabels(), TreeIsRooted()

Examples

lowTree <- BalancedTree(6, lengths = c(1, 1, 4, 4, 4, 1, 1, 4, 4, 4))
plot(lowTree)
Treeness(lowTree)
highTree <- BalancedTree(6, lengths = c(6, 6, 1, 1, 1, 6, 6, 1, 1, 1))
plot(highTree)
Treeness(c(lowTree, highTree))

TreeTools documentation built on April 23, 2026, 5:06 p.m.