View source: R/RcppExports-manual.R
| root_on_node | R Documentation |
root_on_node()Direct entry point to root_on_node(); recommended for expert use only.
RootTree() checks that input is properly formatted and is recommended
for general use.
root_on_node(phy, outgroup)
phy |
Minimally, a named list with entries |
outgroup |
Integer specifying index of leaf or node to set as the outgroup. |
phy may be supplied in any valid edge order.
root_on_node() returns phy rooted on the specified node, in
preorder, with nodes renumbered accordingly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.