| Cherries | R Documentation |
Cherries() counts the number of vertices in a binary tree whose children
are both leaves.
Cherries(tree, nTip)
## S3 method for class 'phylo'
Cherries(tree, nTip = NTip(tree))
## S3 method for class 'numeric'
Cherries(tree, nTip)
tree |
A binary tree, of class |
nTip |
Number of leaves in tree. |
Cherries() returns an integer specifying the number of nodes whose
children are both leaves.
Equations for the number of cherries expected under uniform and Yule tree models are derived by \insertCiteMcKenzie2000;textualTreeTools.
Martin R. Smith (martin.smith@durham.ac.uk)
Other tree properties:
ConsensusWithout(),
EdgeRatio(),
LongBranch(),
MatchEdges(),
NSplits(),
NTip(),
NodeNumbers(),
PathLengths(),
SplitsInBinaryTree(),
TipLabels(),
TreeIsRooted(),
Treeness()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.