Cherries() counts the number of vertices in a binary tree whose children
are both leaves.
Cherries(tree, nTip)# S3 method for phylo
Cherries(tree, nTip = NTip(tree))
# S3 method for numeric
Cherries(tree, nTip)
Cherries() returns an integer specifying the number of nodes whose
children are both leaves.
Equations for the number of cherries expected under uniform and Yule tree models are derived by McKenzie2000;textualTreeTools.
A binary tree, of class phylo; or a matrix corresponding to its
edge matrix.
Number of leaves in tree.
Other tree properties:
ConsensusWithout(),
EdgeRatio(),
LongBranch(),
MatchEdges(),
NSplits(),
NTip(),
NodeNumbers(),
PathLengths(),
SplitsInBinaryTree(),
TipLabels(),
TreeIsRooted(),
Treeness()