Skip to contents

Reports the ratio of tree length associated with external edges (i.e. edges whose child is a leaf) and internal edges. Where tree length is dominated by internal edges, variation between tips is dominantly controlled by phylogenetic history.

Usage

EdgeRatio(x)

# S3 method for class 'phylo'
EdgeRatio(x)

Arguments

x

A tree of class phylo.

Value

EdgeRatio() returns a numeric specifying the ratio of external to internal edge length (> 1 means the length of a tree is predominantly in external edges), with attributes external, internal, and total specifying the total length associated with edges of that nature.