| EdgeRatio | R Documentation |
Reports the ratio of tree length associated with external edges (i.e. edges whose child is a leaf) and internal edges. Where tree length is dominated by internal edges, variation between tips is dominantly controlled by phylogenetic history.
EdgeRatio(x)
## S3 method for class 'phylo'
EdgeRatio(x)
x |
A tree of class |
EdgeRatio() returns a numeric specifying the ratio of external
to internal edge length (> 1 means the length of a tree is predominantly
in external edges), with attributes external, internal, and total
specifying the total length associated with edges of that nature.
Martin R. Smith (martin.smith@durham.ac.uk)
Other tree properties:
Cherries(),
ConsensusWithout(),
LongBranch(),
MatchEdges(),
NSplits(),
NTip(),
NodeNumbers(),
PathLengths(),
SplitsInBinaryTree(),
TipLabels(),
TreeIsRooted(),
Treeness()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.