Learn R Programming

TreeTools (version 2.4.1)

EdgeRatio: Ratio of external:internal edge length

Description

Reports the ratio of tree length associated with external edges (i.e. edges whose child is a leaf) and internal edges. Where tree length is dominated by internal edges, variation between tips is dominantly controlled by phylogenetic history.

Usage

EdgeRatio(x)

# S3 method for phylo EdgeRatio(x)

Value

EdgeRatio() returns a numeric specifying the ratio of external to internal edge length (> 1 means the length of a tree is predominantly in external edges), with attributes external, internal, and total

specifying the total length associated with edges of that nature.

Arguments

x

A tree of class phylo.

See Also

Other tree properties: Cherries(), ConsensusWithout(), LongBranch(), MatchEdges(), NSplits(), NTip(), NodeNumbers(), PathLengths(), SplitsInBinaryTree(), TipLabels(), TreeIsRooted(), Treeness()