View source: R/LongBranchScore.R
| LongBranch | R Documentation |
The long branch (LB) score \insertCiteStruck2014TreeTools measures the deviation of the average pairwise patristic distance of a leaf from all other leaves in a tree, relative to the average leaf-to-leaf distance.
LongBranch(tree)
tree |
A tree of class |
Struck2014;textualTreeTools proposes the standard deviation of LB scores as a measure of heterogeneity that can be compared between trees; and the upper quartile of LB scores as "a representative value for the taxa with the longest branches".
LongBranch() returns a vector giving the long branch score for
each leaf in tree, or a list of such vectors if tree is a list.
Results are given as raw deviations, without multiplying by 100 as proposed
by \insertCiteStruck2014;textualTreeTools.
Martin R. Smith (martin.smith@durham.ac.uk)
Other tree properties:
Cherries(),
ConsensusWithout(),
EdgeRatio(),
MatchEdges(),
NSplits(),
NTip(),
NodeNumbers(),
PathLengths(),
SplitsInBinaryTree(),
TipLabels(),
TreeIsRooted(),
Treeness()
tree <- BalancedTree(8, lengths = c(rep(2, 4), 5:7, rep(2, 4), rep(1, 3)))
lb <- LongBranch(tree)
tree$tip.label <- paste(tree$tip.label, signif(lb, 3), sep = ": ")
plot(tree, tip.col = SupportColour((1 - lb) / 2), font = 2)
# Standard deviation of LB scores allows comparison with other trees
sd(lb)
evenLengths <- BalancedTree(8, lengths = jitter(rep(1, 14)))
sd(LongBranch(evenLengths))
# Upper quartile identifies taxa with longest branches
threshold <- quantile(lb, 0.75)
tree$tip.label[lb > threshold]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.