View source: R/ConsistentSplits.R
| SplitConsistent | R Documentation |
SplitConsistent() and SplitConflict() determine whether a series of
splits haystack are consistent with or contradict the focal split needle.
SplitConsistent(needle, haystack)
SplitConflicts(needle, haystack)
needle |
Splits object containing the single split to evaluate |
haystack |
Splits object, or list thereof, containing the splits to
compare against |
SplitConsistent() returns a list of logical vectors.
Each list item corresponds to an entry in haystack, reporting whether each
split is consistent with (TRUE) or in conflict with (FALSE) needle.
SplitConflicts() returns the inverse.
Martin R. Smith (martin.smith@durham.ac.uk)
Other split manipulation functions:
DropTip(),
Subsplit(),
TrivialSplits()
splits1 <- as.Splits(BalancedTree(8))
splits2 <- as.Splits(PectinateTree(8))
summary(splits1[[4]])
SplitConsistent(splits1[[4]], splits2)
SplitConflicts(splits1[[4]], list(splits1, splits2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.