| Treeness | R Documentation |
Treeness (also termed stemminess) is the proportion of a tree's length found on internal branches \insertCiteLanyon1988TreeTools. Insofar as external branches do not contain phylogenetic (grouping) signal, trees with a high treeness can be interpreted as containing a higher signal:noise ratio \insertCitePhillips2003TreeTools.
Treeness(tree)
Stemminess(tree)
tree |
A tree of class |
Treeness() returns a numeric vector reporting the treeness of each
tree.
Martin R. Smith (martin.smith@durham.ac.uk)
Other tree properties:
Cherries(),
ConsensusWithout(),
EdgeRatio(),
LongBranch(),
MatchEdges(),
NSplits(),
NTip(),
NodeNumbers(),
PathLengths(),
SplitsInBinaryTree(),
TipLabels(),
TreeIsRooted()
lowTree <- BalancedTree(6, lengths = c(1, 1, 4, 4, 4, 1, 1, 4, 4, 4))
plot(lowTree)
Treeness(lowTree)
highTree <- BalancedTree(6, lengths = c(6, 6, 1, 1, 1, 6, 6, 1, 1, 1))
plot(highTree)
Treeness(c(lowTree, highTree))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.